[elephant-cvs] CVS elephant/src/db-clsql
ieslick
ieslick at common-lisp.net
Sat Apr 21 17:22:50 UTC 2007
Update of /project/elephant/cvsroot/elephant/src/db-clsql
In directory clnet:/tmp/cvs-serv3920/src/db-clsql
Modified Files:
package.lisp sql-controller.lisp
Log Message:
Check for cross-store loading errors in multi-store operation; more documentation; backend language to data store language
--- /project/elephant/cvsroot/elephant/src/db-clsql/package.lisp 2007/04/12 02:47:24 1.4
+++ /project/elephant/cvsroot/elephant/src/db-clsql/package.lisp 2007/04/21 17:22:39 1.5
@@ -20,7 +20,7 @@
(defpackage db-clsql
(:use :common-lisp :uffi :cl-base64
- :elephant :elephant-memutil :elephant-backend
+ :elephant :elephant-memutil :elephant-data-store
:elephant-utils
#+sbcl :sb-thread
))
--- /project/elephant/cvsroot/elephant/src/db-clsql/sql-controller.lisp 2007/04/12 02:47:24 1.24
+++ /project/elephant/cvsroot/elephant/src/db-clsql/sql-controller.lisp 2007/04/21 17:22:40 1.25
@@ -88,10 +88,10 @@
(eval-when (:compile-toplevel :load-toplevel)
- (register-backend-con-init :clsql 'sql-test-and-construct))
+ (register-data-store-con-init :clsql 'sql-test-and-construct))
(defun sql-test-and-construct (spec)
- "Entry function for making SQL backend controllers"
+ "Entry function for making SQL data store controllers"
(if (sql-store-spec-p spec)
(make-instance 'sql-store-controller
:spec (if spec spec
@@ -167,7 +167,7 @@
;; ISE NOTE: Much of the index management functionality is common between
;; bdb and sql - we could lift this along with indices and indices-cache
;; up to the main elephant code base and introduce a new update-index
;; generic function to handle the backend specific method for updating
(defmethod map-indices (fn (bt sql-indexed-btree))
(maphash fn (indices-cache bt)))
More information about the Elephant-cvs
@@ -167,7 +167,7 @@
;; bdb and sql - we could lift this along with indices and indices-cache
;; up to the main elephant code base and introduce a new update-index
-;; generic function to handle the backend specific method for updating
+;; generic function to handle the data store specific method for updating
(defmethod map-indices (fn (bt sql-indexed-btree))
(maphash fn (indices-cache bt)))
mailing list